==> haskell-quickcheck-text-0.1.2.1-204-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-quickcheck-text.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 quickcheck-text
version:              0.1.2.1
visibility:           public
id:                   quickcheck-text-0.1.2.1-Dd0XcfSKld7LrqPwjbzYXn
key:                  quickcheck-text-0.1.2.1-Dd0XcfSKld7LrqPwjbzYXn
license:              MIT
copyright:            2015-2016 Sharif Olorin and others
maintainer:           sio@tesser.org
author:               Sharif Olorin
homepage:             https://github.com/olorin/quickcheck-text
synopsis:             Alternative arbitrary instance for Text
description:
    The usual Arbitrary instance for Text
    (in
    <https://hackage.haskell.org/package/quickcheck-instances quickcheck-instances>)
    only has single-byte
    instances and so isn'\''t an ideal representation of a valid UTF-8
    character. This package has generators for one-, two- and three-byte
    UTF-8 characters (all that are currently in use).

category:             Text
abi:                  6d494aeb2ae1aec1dff3ec41af8b0ac5
exposed:              True
exposed-modules:      Data.Text.Arbitrary Test.QuickCheck.Utf8
import-dirs:          /usr/lib/ghc-9.4.8/site-local/quickcheck-text-0.1.2.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/quickcheck-text-0.1.2.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/quickcheck-text-0.1.2.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-quickcheck-text
hs-libraries:         HSquickcheck-text-0.1.2.1-Dd0XcfSKld7LrqPwjbzYXn
depends:
    QuickCheck-2.15.0.1-7dsjbuPrJB87A5nQdB1dNE base-4.17.2.1
    binary-0.8.9.1 bytestring-0.11.5.3 text-2.0.2

haddock-interfaces:
    /usr/share/doc/haskell-quickcheck-text/html/quickcheck-text.haddock

haddock-html:         /usr/share/doc/haskell-quickcheck-text/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-quickcheck-text-0.1.2.1-205-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-quickcheck-text.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 quickcheck-text
version:              0.1.2.1
visibility:           public
id:                   quickcheck-text-0.1.2.1-7bXOGLultie4EdEVWFW5UK
key:                  quickcheck-text-0.1.2.1-7bXOGLultie4EdEVWFW5UK
license:              MIT
copyright:            2015-2016 Sharif Olorin and others
maintainer:           sio@tesser.org
author:               Sharif Olorin
homepage:             https://github.com/olorin/quickcheck-text
synopsis:             Alternative arbitrary instance for Text
description:
    The usual Arbitrary instance for Text
    (in
    <https://hackage.haskell.org/package/quickcheck-instances quickcheck-instances>)
    only has single-byte
    instances and so isn'\''t an ideal representation of a valid UTF-8
    character. This package has generators for one-, two- and three-byte
    UTF-8 characters (all that are currently in use).

category:             Text
abi:                  2eaf61442a1d092a760498c55943fbb4
exposed:              True
exposed-modules:      Data.Text.Arbitrary Test.QuickCheck.Utf8
import-dirs:          /usr/lib/ghc-9.4.8/site-local/quickcheck-text-0.1.2.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/quickcheck-text-0.1.2.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/quickcheck-text-0.1.2.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-quickcheck-text
hs-libraries:         HSquickcheck-text-0.1.2.1-7bXOGLultie4EdEVWFW5UK
depends:
    QuickCheck-2.15.0.1-9BbRJGxXLRp2lnC2CpyIBM base-4.17.2.1
    binary-0.8.9.1 bytestring-0.11.5.3 text-2.0.2

haddock-interfaces:
    /usr/share/doc/haskell-quickcheck-text/html/quickcheck-text.haddock

haddock-html:         /usr/share/doc/haskell-quickcheck-text/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
